@@ -13,43 +13,30 @@
 		if(is.null(separatedX) || separatedX) 
 			statTest="t" else
 			statTest="F"
-	
-{
-		### mettere qui la pulizia degli statTest per dependence test
-	  if(statTest=="NA"){ #for missing values
+
+	if((testType=="rotation") && statTest%in%c("Fisher","Wilcoxon","Kruskal-Wallis","ranks","chisq","chisq.separated") ){
+	  warning("Rotations are not allowed for Fisher exact test, permutations will be used instead.")
+	  testType="permutation"
+	}
+
+    if(statTest=="NA"){ #for missing values
 	    #same function for permutation and rotation tests
 	      test <- .NA.dependence.nptest
-	  } else
-    if(statTest%in%c("sum","t")){
-			if(testType=="rotation"){
-				test <- .t.rotation.nptest
-			} else # not a rotation test
+	  } else if(statTest%in%c("sum","t")){
 				test <- .t.dependence.nptest		
-		} else  
-		if(statTest=="F"){ #ANOVAtype test, 1 column for each column of Y summarizing the dependence with all Xs			
-			if(testType=="rotation"){
-				test <- .F.rotation.nptest
-			} else #not a rotation test
+		} else if(statTest=="F"){ #ANOVAtype test, 1 column for each column of Y summarizing the dependence with all Xs			
 				test <- .F.dependence.nptest
-		} else
-		if(statTest=="Fisher"){ 
-			if(testType=="rotation"){
-				warning("Rotations are not allowed for Fisher exact test, permutations will be used instead.")
-				testType="permutation"
-			} else #not a rotation test
+		} else if(statTest=="Fisher"){
 				test <- .fisher.dependence.nptest
 		} else if(statTest%in%c("Wilcoxon","Kruskal-Wallis","ranks")){
-			if(testType=="rotation"){
-				warning("Rotations are not allowed for Wilcoxon (i.e. ranks) test, permutations will be used instead.")
-				testType="permutation"
-			} else ## permutation test
 				test <- .rank.dependence.nptest
 		} else if(statTest%in%c("chisq","chisq.separated")){
 			test <- .chisq.dependence.nptest
 # 		} else if(statTest%in%"Kolmogorov-Smirnov"){
 # 			test <- .kolmogorov.dependence.nptest
 		} else	{stop("This test statistic is not valid, nothing done."); return()}
-		if(statTest%in%c("Fisher","Wilcoxon","Kruskal-Wallis","ranks","chisq","Kolmogorov-Smirnov")) 
+  
+if(statTest%in%c("Fisher","Wilcoxon","Kruskal-Wallis","ranks","chisq","Kolmogorov-Smirnov")) {
 			if(length(unique(data$Z))>1 ) warning("Covariates Z can not be used in this test. Use strata instread.")
 	}
   environment(test) <- sys.frame(sys.nframe())
@@ -62,7 +49,7 @@
 .t.dependence.nptest <- function(){
 	#data <- .orthoZ(data) #if Z is.null, it doesn't make anything
 	N=nrow(data$Y)
-  perms <- make.permSpace(1:N,perms,return.permIDs=return.permIDs,testType=testType, Strata=data$Strata)
+  perms <- make.permSpace(1:N,perms,return.permIDs=TRUE,testType=testType, Strata=data$Strata)
 	#search for intercept in the model
 	intercept=.getIntercept(data$X)
 	if(any(intercept)) {
@@ -103,13 +90,16 @@
 		data$Y=scale(data$Y,scale=FALSE)
 	}
 	
-	q=ncol(data$X)#-sum(intercept) #just a trick, it should be subtracetd to N, not to q
+	
 	
 #	environment(.prod2F) <- sys.frame(sys.nframe())
 	P=.get.eigenv.proj.mat(data)
 	permT=.prod.perms.P(data,perms,testType=testType,P)
 	permT=.prod2F(permT,data)
-	if(any(intercept)) permT =permT * (N-q-sum(intercept))/(N-q)
+  if(any(intercept)) {
+    q=ncol(data$X)#-sum(intercept) #just a trick, it should be subtracetd to N, not to q
+    permT =permT * (N-q-sum(intercept))/(N-q)
+  }
 	
 	colnames(permT) = .getTNames(data$Y,permT=permT)
 	rownames(permT)=.getTRowNames(permT)		
@@ -120,7 +110,7 @@
 .rank.dependence.nptest <- function(){
 	data$Y=apply(data$Y,2,rank)
 	N=nrow(data$Y)
-	perms <- make.permSpace(1:N,perms,return.permIDs=return.permIDs,testType=testType, Strata=data$Strata)
+	perms <- make.permSpace(1:N,perms,return.permIDs=TRUE,testType=testType, Strata=data$Strata)
 	
 	#search for intercept in the model
 	intercept=.getIntercept(data$X)
@@ -153,7 +143,7 @@
 	if(any(apply(data$Y,2,function(y) length(unique(y))!=2 ))) stop("Only factor or dichotomous variables are allowed with Fisher exact test. Nothing done.")
 	
 	N=nrow(data$Y)
-	perms <- make.permSpace(1:N,perms,return.permIDs=return.permIDs,testType=testType, Strata=data$Strata)
+	perms <- make.permSpace(1:N,perms,return.permIDs=TRUE,testType=testType, Strata=data$Strata)
 	
 	#search for intercept in the model
 	intercept=.getIntercept(data$X)
@@ -178,7 +168,7 @@
 	if(any(apply(data$Y,2,function(y) length(unique(y))!=2 ))) stop("Only factor or dichotomous variables are allowed with Chi Squared test. Nothing done.")
 	
 	N=nrow(data$Y)
-	perms <- make.permSpace(1:N,perms,return.permIDs=return.permIDs,testType=testType, Strata=data$Strata)
+	perms <- make.permSpace(1:N,perms,return.permIDs=TRUE,testType=testType, Strata=data$Strata)
 	
 	#search for intercept in the model
 	intercept=.getIntercept(data$X)
